main.main

copydraw.main.main(for_calibration=False, stim=None, block_nr=None)

Main function to run the CopyDraw experiment.

Initializes the paradigm and executes a block of trials. Can be configured for calibration mode with reduced trial duration and single trial.

Parameters

Name Type Description Default
for_calibration bool If True, runs in calibration mode with 1 trial and 0.2s letter time. False
stim str Stimulus identifier for the block. None
block_nr int Block number for the experiment. If None, the next block number is determined automatically. None